Project description
#developed by :Roni Das
#Date : 30/05/2021
allneo is a Python package that provides fast, flexible, and expressive toolkit this helps to work with neo4j graph database easyily and intuitively. It aims to be the fundamental high-level building block for doing practical, real world operation and data analysis in Python. Additionally, it has the broader goal of becoming the most powerful and flexible open source neo4j operation and manipulation tool available in python. We are trying to make its way toward this goal.

allneo is well suited for many different kinds of neo4j operations

